# Changelog

## [0.2.0](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.21...inference-0.2.0) (2026-02-16)


### Features

* **inference multio:** Add `ORIGIN` magic string for stream in metadata ([#71](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/71)) ([4e25267](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/4e25267100210ddbd592b2a1da2cdb022da2382d))


### Bug Fixes

* **mir:** Update README.md ([#69](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/69)) ([b117fea](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/b117feae172f7fedd3b248971962ca2efec2255d))

## [0.1.21](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.20...inference-0.1.21) (2026-01-13)


### Bug Fixes

* **multio:** Allow empty `model` ([#65](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/65)) ([4233b72](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/4233b72a1fcd8f16489c387d229d4118250c0ae9))

## [0.1.20](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.19...inference-0.1.20) (2026-01-09)


### Bug Fixes

* **inference mir:** Missing template kwargs ([#63](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/63)) ([f00e41e](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/f00e41e0a4323d8d83d2d00e55a0c1b11b7ebd2f))

## [0.1.19](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.18...inference-0.1.19) (2025-11-28)


### Bug Fixes

* **inference multio:** Issue with model validation for ens number ([#60](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/60)) ([fbf4f20](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/fbf4f20f097d9c77fb659a549783665743095387))

## [0.1.18](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.17...inference-0.1.18) (2025-11-18)


### Bug Fixes

* Explicitly set misc-timeIncrementInSeconds to 0 ([#57](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/57)) ([efb6a3f](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/efb6a3f972304e8e04177a97f4f5e3095664d811))

## [0.1.17](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.16...inference-0.1.17) (2025-11-06)


### Features

* Add flexible mappings to opendata ([#55](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/55)) ([34d2a47](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/34d2a477cc4e027491d2deb014c562fc1c4fd760))


### Bug Fixes

* Upgrade to inference: 0.8.1 ([#54](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/54)) ([a006085](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/a00608589fa2418111943713a5f9647939f1b8b1))

## [0.1.16](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.15...inference-0.1.16) (2025-10-26)


### Bug Fixes

* Upgrade to inference-0.8 ([#51](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/51)) ([c8de39b](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/c8de39bcb7cc31b132eb97f55449490bfc90490b))

## [0.1.15](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.14...inference-0.1.15) (2025-10-17)


### Bug Fixes

* Provide upper bound on anemoi-inference ([#50](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/50)) ([71ac485](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/71ac485b436aad59c96c821f75eeae7d8ec7bdcd))

## [0.1.14](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.13...inference-0.1.14) (2025-10-03)


### Bug Fixes

* **inference,opendata:** Override `optional_inputs` due to update ([#48](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/48)) ([8f8d3d8](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/8f8d3d8ba874cb92a80ea453fa97183c0e0d0cc0))

## [0.1.13](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.12...inference-0.1.13) (2025-10-02)


### Features

* **inference, polytope:** Allow for grid / area to be set in config ([#46](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/46)) ([61e5d97](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/61e5d972e67d64d20101678ae14c2055e32ad038))

## [0.1.12](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.11...inference-0.1.12) (2025-09-30)


### Features

* **inference.multio:** Add sinks argument to plan output ([#44](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/44)) ([0b33b89](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/0b33b89e7c59bd4865dfe43eee5cdce2cab4794d))

## [0.1.11](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.10...inference-0.1.11) (2025-09-18)


### Bug Fixes

* [opendata] Use `od` instead of `ea` ([#42](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/42)) ([2457540](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/245754030d29790b57ce1bd1764f905e77601674))

## [0.1.10](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.9...inference-0.1.10) (2025-09-16)


### Bug Fixes

* Move mir version to lower bound ([#40](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/40)) ([96792b1](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/96792b10903a950e756995404b4f525ef40fed8f))

## [0.1.9](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.8...inference-0.1.9) (2025-09-15)


### Bug Fixes

* Update mir version ([#38](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/38)) ([5601fab](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/5601fab1e7e5eaff171017186059446ff934eb76))

## [0.1.8](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.7...inference-0.1.8) (2025-09-11)


### Features

* **multio:** Option to copy initial state diagnostics from grib ([#36](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/36)) ([14b4bdd](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/14b4bdd6b3f69a33b1c5a71a043c76d982140ac9))

## [0.1.7](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.6...inference-0.1.7) (2025-09-11)


### Features

* [inference-multio] Add archive collector ([#34](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/34)) ([c9ba2ec](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/c9ba2ecfc9c541fa4166a3c1bcce08aa0ef4efc1))
* [inference-multio] Add disambiguous entrypoint ([#33](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/33)) ([32707df](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/32707df09126b8edf2a00a65f0acefc231e87d58))

## [0.1.6](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.5...inference-0.1.6) (2025-09-09)


### Bug Fixes

* [inference-multio] Address timing and generatingProcessIdentifier issues ([#31](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/31)) ([405837c](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/405837c889e5d50baf4fb063362a85ca6eaa9240))

## [0.1.5](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.4...inference-0.1.5) (2025-09-09)


### Features

* [inference-multio] Improvements on timespan and nans ([#30](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/30)) ([2e8aa90](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/2e8aa90bc9ef7362da739cd9283b02d41a08bbfd))


### Documentation

* Update multio readme ([#27](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/27)) ([b4373f8](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/b4373f834d88356555531eb257c4087726631e94))

## [0.1.4](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.3...inference-0.1.4) (2025-08-26)


### Features

* Add preprocessors to test dynamics  ([#25](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/25)) ([0e98f93](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/0e98f939b3d1c5a8b94d2082ef529062113c1e9f))

## [0.1.3](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.2...inference-0.1.3) (2025-08-14)


### Bug Fixes

* mir grid handling due to anemoi-inference ([#23](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/23)) ([a65ffa4](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/a65ffa49b6f4785bf46b6ae763ac369878e3ec1b))

## [0.1.2](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.1...inference-0.1.2) (2025-08-13)


### Bug Fixes

* updates from anemoi-inference ([#18](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/18)) ([91194fb](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/91194fbb30ea9279d255e1f17cfab7b4e31533c7))

## [0.1.1](https://github.com/ecmwf/anemoi-plugins-ecmwf/compare/inference-0.1.0...inference-0.1.1) (2025-08-05)


### Features

* **inference opendata:** Add opendata input ([#15](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/15)) ([990fa3d](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/990fa3ddd60b058005f6cb33c2d53eea289c632d))
* **inference regrid:** Add regrid preprocessor ([#16](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/16)) ([af00ffe](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/af00ffe5d57f3e5b8b65bbcba7791fa00070d1ba))


### Bug Fixes

* **inference mir:** ensure grid is str ([6397681](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/63976811396341e83b0c421c03fd572f78d28b53))
* **opendata:** Add default to pop ([5e4ef50](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/5e4ef504c11bfb04e820a5cf46d62add965772ba))

## 0.1.0 (2025-07-28)


### Bug Fixes

* Reorganise repo ([#13](https://github.com/ecmwf/anemoi-plugins-ecmwf/issues/13)) ([8b47509](https://github.com/ecmwf/anemoi-plugins-ecmwf/commit/8b47509110db13f106f11397cbb2f89d80e82952))
